@@ -3,9 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Change audio file anchors to audio elements
 
-our $VERSION = '0.0201';
-
-use v5.20.0;
+our $VERSION = '0.0203';
 
 use Statocles::Base 'Class';
 with 'Statocles::Plugin';
@@ -36,7 +34,7 @@ sub register {
     my ($self, $site) = @_;
     $site->on(build => sub {
         my ($event) = @_;
-        for my $page ($event->pages->@*) {
+        for my $page (@{ $event->pages }) {
             $page = $self->audio_tag($page);
         }
     });
@@ -56,7 +54,7 @@ Statocles::Plugin::AudioTag - Change audio file anchors to audio elements
 
 =head1 VERSION
 
-version 0.0201
+version 0.0203
 
 =head1 SYNOPSIS
 
